CaptureNetworkTrafficCommand (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class CaptureNetworkTrafficCommand

    java.lang.Object
      org.openqa.selenium.server.commands.Command
          org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand

    public class CaptureNetworkTrafficCommand

extends Command

Nested Class Summary
`static class` | `CaptureNetworkTrafficCommand.Entry`
`static class` | `CaptureNetworkTrafficCommand.Header`

Constructor Summary
`CaptureNetworkTrafficCommand(java.lang.String type)`

Method Summary
`static void` | `capture(CaptureNetworkTrafficCommand.Entry entry)`
`static void` | `clear()`
`java.lang.String` | `execute()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### CaptureNetworkTrafficCommand

    public CaptureNetworkTrafficCommand(java.lang.String type)

Method Detail

### clear

    public static void clear()

### capture

    public static void capture(CaptureNetworkTrafficCommand.Entry entry)

### execute

    public java.lang.String execute()

  Specified by:
    `execute` in class `Command`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.